@@ -4,7 +4,7 @@
 """
 
 
-from .npu import api, predict, compile, train, export, upload_data
+from .npu import api, predict, compile, train, export, upload_data, export_task_result, print
 from . import vision, optim, loss, metrics
 from .core import DataLoader
 from .version import __version__, _module
@@ -15,4 +15,6 @@ predict.__module__ = _module
 compile.__module__ = _module
 train.__module__ = _module
 export.__module__ = _module
+export_task_result.__module__ = _module
 upload_data.__module__ = _module
+print.__module__ = _module
