@@ -34,6 +34,7 @@ class DataLoader(object):
         else:
             for i, s in enumerate(self.shape):
                 s[0] += data_part[i][0]
+        length = 1
 
         def get_size(byte_list):
             return sum(len(d) for d in byte_list)
@@ -45,6 +46,7 @@ class DataLoader(object):
         hashes = [hashlib.md5(d) for d in d_bytes]
         size = get_size(d_bytes)
         for data_part in itertools.islice(self.numpy(), 1, None):
+            length += 1
             d_bytes = get_bytes(data_part)
             size += get_size(d_bytes)
             for i, d in enumerate(d_bytes):
@@ -52,7 +54,7 @@ class DataLoader(object):
         _hash = hashlib.md5()
         for __hash in hashes:
             _hash.update(__hash.digest())
-        return _hash.hexdigest(), size
+        return _hash.hexdigest(), size, length
 
 
 
