@@ -40,4 +40,4 @@ class Dataset(object):
         Property for test subset
         :return: slice
         """
-        return self[self.__val_end:self.__train_end]
+        return self[self.__val_end:self.__test_end]
