@@ -32,8 +32,8 @@ def MaskedLM(pretrained=""):
     return nlp_constructor("MaskedLM", pretrained)
 
 
-def CasualLM(pretrained=""):
-    return nlp_constructor("CasualLM", pretrained)
+def CausalLM(pretrained=""):
+    return nlp_constructor("CausalLM", pretrained)
 
 
 def LMHead(pretrained=""):
